@@ -10,7 +10,7 @@ global_lock = threading.Lock()
 
 def _merge(msg, frame: bool = True) -> str:
     if isinstance(msg, dict):
-        msg = f'\n{json.dumps(msg, indent=2)}'
+        msg = f'\n{json.dumps(msg, indent=2, ensure_ascii=False)}'
     elif isinstance(msg, tuple):
         msg = " ".join([str(x).strip() for x in msg])
         if frame:
@@ -25,7 +25,7 @@ def _merge(msg, frame: bool = True) -> str:
         if frame:
             msg = f'[{msg}]'
 
-    return msg
+    return msg.strip()
 
 
 @unique
@@ -36,21 +36,6 @@ class LoggerLevel(IntEnum):
     SILENT = 4
 
 
-def get_call_location_info(func):
-    def wrapper(*args, **kwargs):
-        cf = inspect.currentframe()
-
-        line_no = cf.f_back.f_lineno
-        file_name = cf.f_back.f_code.co_filename
-        file_name = os.path.basename(file_name)
-        kwargs.update({
-            'line_no': line_no,
-            'file_name': file_name})
-        return func(*args, **kwargs)
-
-    return wrapper
-
-
 class Logger:
     TRACE = LoggerLevel.TRACE
     DEBUG = LoggerLevel.DEBUG
@@ -84,21 +69,19 @@ class Logger:
     def info(self, *msg):
         self._log(Logger.INFO, *msg)
 
-    @get_call_location_info
-    def debug(self, *msg, **kwargs):
-        self._log(Logger.DEBUG, *msg, **kwargs)
+    def debug(self, *msg):
+        self._log(Logger.DEBUG, *msg)
 
-    @get_call_location_info
-    def trace(self, *msg, **kwargs):
-        self._log(Logger.TRACE, *msg, **kwargs)
+    def trace(self, *msg):
+        self._log(Logger.TRACE, *msg)
 
-    def _log(self, log_level: LoggerLevel, *msg, line_no=None, file_name=None):
+    def _log(self, log_level: LoggerLevel, *msg):
         if self.skip_repeat:
             if self.last_msg == msg:
                 return
             self.last_msg = msg
 
-        if len(msg) == 0:
+        if msg_length := len(msg) == 0:
             return
 
         if not isinstance(log_level, LoggerLevel):
@@ -107,10 +90,15 @@ class Logger:
         if self.level > log_level:
             return
 
-        if len(msg) == 0:
-            return
+        if self.level <= self.DEBUG:
+            cf = inspect.currentframe()
+            line_no = cf.f_back.f_back.f_lineno
+            file_name = cf.f_back.f_back.f_code.co_filename
+            file_name = os.path.basename(file_name)
+        else:
+            line_no = None
 
-        des = _merge(msg[0], frame=False)
+        des = _merge(msg[0], frame=msg_length != 1)
 
         msg = [f' {_merge(x)}' for x in msg[1:]]
         msg.insert(0, des)
